/**
 * Copyright 2012 Julien Eluard
 * This project includes software developed by Julien Eluard: https://github.com/jeluard/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.github.jeluard.guayaba.base;

import com.google.common.base.Function;

/**
 * A {@link Function} that only accept a subset of input values.
 *
 * @see <a href="http://en.wikipedia.org/wiki/Partial_function">
 * @see <a href="https://github.com/scala/scala/blob/master/src/library/scala/PartialFunction.scala">
 */
public interface PartialFunction<I, O> extends Function<I, O> {

  /**
   * @param input
   * @return true if this function can be applied to specified `input` 
   */
  boolean isDefinedAt(I input);

}