/**
 * Copyright 2012 Julien Eluard
 * This project includes software developed by Julien Eluard: https://github.com/jeluard/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.github.jeluard.guayaba.lang;

import com.github.jeluard.guayaba.lang.reflect.Fields;
import com.google.common.base.Objects;
import com.google.common.base.Preconditions;

import java.lang.reflect.Field;

/**
 * Helper methods for {@link Objects.ToStringHelper}.
 */
public final class ToStringBuilders {

  private ToStringBuilders() {
  }

  /**
   * @param object
   * @return a {@link String} representation of specified object.
   */
  public static String reflectionToString(final Object object) {
    Preconditions.checkNotNull(object, "null object");

    final Objects.ToStringHelper toStringHelper = Objects.toStringHelper(object);
    for (final Field field : Classes.allFields(object.getClass())) {
      field.setAccessible(true);
      toStringHelper.add(field.getName(), Fields.get(field, object));
    }
    return toStringHelper.toString();
  }

}