/**
 * Copyright 2012 Julien Eluard
 * This project includes software developed by Julien Eluard: https://github.com/jeluard/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.github.jeluard.guayaba.lang.reflect;

import com.google.common.base.Preconditions;

import java.lang.reflect.Field;

/**
 * Helper methods for {@link Field}.
 */
public final class Fields {

  private Fields() {
  }

  /**
   * @param <T>
   * @param field
   * @param object
   * @return value of specified {@link Field}
   */
  public static <T> T get(final Field field, final Object object) {
    Preconditions.checkNotNull(field, "null field");
    Preconditions.checkNotNull(object, "null object");

    if (!field.isAccessible()) {
      field.setAccessible(true);
    }

    try {
      return (T) field.get(object);
    } catch (IllegalAccessException e) {
      //Cannot happen as we force accessibility.
      throw new IllegalStateException(e);
    }
  }

}