/**
 * Copyright 2012 Julien Eluard
 * This project includes software developed by Julien Eluard: https://github.com/jeluard/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.github.jeluard.guayaba.util;

import com.google.common.base.Preconditions;

import java.util.Iterator;
import java.util.ServiceLoader;

/**
 * Helper methods for {@link ServiceLoader}.
 */
public final class ServiceLoaders {

  private ServiceLoaders() {
  }

  /**
   * @param <T>
   * @param type
   * @param classLoader
   * @return first implementation of `type` as reported by {@link ServiceLoader#load(java.lang.Class, java.lang.ClassLoader)}, if any
   */
  public static <T> T load(final Class<T> type, final ClassLoader classLoader) {
    Preconditions.checkNotNull(type, "null type");
    Preconditions.checkNotNull(classLoader, "null classLoader");

    final Iterator<T> iterator = ServiceLoader.load(type, classLoader).iterator();

    Preconditions.checkArgument(iterator.hasNext(), iterator);

    return iterator.next();
  }

}